@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 __title__ = 'baidupcsapi'
-__version__ = '0.2.12'
-__author__ = 'mozillazg,latyas'
+__version__ = '0.3.2'
+__author__ = 'latyas'
 __license__ = 'MIT'
 
-from .api import PCS
\ No newline at end of file
+from .api import PCS
